/* -----------------------------------------------------------------------------------
                                     tft_pindefs.h

                     Pinbelegungen TFT-Display zu Controller


     28.01.2019  R. Seelig
   ----------------------------------------------------------------------------------- */

#ifndef in_tft_pindefs
  #define in_tft_pindefs

  #include "tftdisplay.h"

  #if (USE_SPI_TFT == 1)

    /*  ------------------------------------------------------------
                        Pinbelegung fuer SPI-Displays
        ------------------------------------------------------------ */

    //  PB6 = NSS, PA5 = SCK, PA6 = MISO, PA7 = MOSI, alternate function fuer SPI = AF0
    #define spi_ss     GPIO6
    #define spi_sck    GPIO5
    #define spi_miso   GPIO6
    #define spi_mosi   GPIO7

    #if (pindefs == 1)


    #endif

    #if (pindefs == 2)


    #endif                                      // pindefs

    // STM32F407VET6 BlackBoard (China)
    #if (pindefs == 3)

      #define lcd_clk    spi_sck        // PA5
      #define lcd_din    spi_mosi       // PA7
      #define lcd_ce     GPIO0          // PA0
      #define lcd_dc     GPIO4          // PA4
      #define lcd_rst    GPIO2          // PA2

      #define lcd_pin_mask      ( lcd_ce | lcd_rst | lcd_dc)
      #define lcd_pin_init()    { gpio_mode_setup(GPIOA, GPIO_MODE_OUTPUT, GPIO_PUPD_NONE, lcd_pin_mask); }

      #define dc_set()          ( gpio_set(GPIOA, lcd_dc) )
      #define dc_clr()          ( gpio_clear(GPIOA, lcd_dc) )
      #define ce_set()          ( gpio_set(GPIOA, lcd_ce) )
      #define ce_clr()          ( gpio_clear(GPIOA, lcd_ce) )
      #define rst_set()         ( gpio_set(GPIOA, lcd_rst) )
      #define rst_clr()         ( gpio_clear(GPIOA, lcd_rst) )
      #define lcd_enable()      ( ce_clr() )
      #define lcd_disable()     ( ce_set() )

    #endif

    #if (pindefs == 4)

      #define lcd_clk    spi_sck        // PA5
      #define lcd_din    spi_mosi       // PA7
      #define lcd_ce     spi_ss         // PB6
      #define lcd_dc     GPIO7          // PC7
      #define lcd_rst    GPIO9          // PA9

      #define lcd_pin_mask      ( lcd_ce | lcd_rst )
      #define lcd_pin_init()    { gpio_mode_setup(GPIOA, GPIO_MODE_OUTPUT, GPIO_PUPD_NONE, lcd_rst);  \
                                  gpio_mode_setup(GPIOC, GPIO_MODE_OUTPUT, GPIO_PUPD_NONE, lcd_dc);   \
                                  gpio_mode_setup(GPIOB, GPIO_MODE_OUTPUT, GPIO_PUPD_NONE, lcd_ce);   }

      #define dc_set()          ( gpio_set(GPIOC, lcd_dc) )
      #define dc_clr()          ( gpio_clear(GPIOC, lcd_dc) )
      #define ce_set()          ( gpio_set(GPIOB, lcd_ce) )
      #define ce_clr()          ( gpio_clear(GPIOB, lcd_ce) )
      #define rst_set()         ( gpio_set(GPIOA, lcd_rst) )
      #define rst_clr()         ( gpio_clear(GPIOA, lcd_rst) )
      #define lcd_enable()      ( ce_clr() )
      #define lcd_disable()     ( ce_set() )

    #endif

    #if (pindefs == 5)

      #define lcd_clk    spi_sck        // PA5
      #define lcd_din    spi_mosi       // PA7
      #define lcd_ce     GPIO6          // PB6
      #define lcd_dc     GPIO10         // PB10
      #define lcd_rst    GPIO8          // PA8

      #define lcd_pin_init()    { gpio_mode_setup(GPIOB, GPIO_MODE_OUTPUT, GPIO_PUPD_NONE, lcd_ce | lcd_dc);  \
                                  gpio_mode_setup(GPIOA, GPIO_MODE_OUTPUT, GPIO_PUPD_NONE, lcd_rst);  }

      #define dc_set()          ( gpio_set(GPIOB, lcd_dc) )
      #define dc_clr()          ( gpio_clear(GPIOB, lcd_dc) )

      #define ce_set()          ( gpio_set(GPIOB, lcd_ce) )
      #define ce_clr()          ( gpio_clear(GPIOB, lcd_ce) )

      #define rst_set()         ( gpio_set(GPIOA, lcd_rst) )
      #define rst_clr()         ( gpio_clear(GPIOA, lcd_rst) )

      #define lcd_enable()      ( ce_clr() )
      #define lcd_disable()     ( ce_set() )

    #endif

  #endif               // USE_SPI_TFT

  #if (USE_8BIT_TFT == 1)
    /*  ------------------------------------------------------------
          Pinbelegung fuer TFT-Displays mit 8-Bit Parallelinterface
        ------------------------------------------------------------ */

    #define intbit(wert,nr)    ((wert) & (1<<nr))
    #define setintbit(wert,nr) (wert |= (1<<nr))
    #define clrintbit(wert,nr) (wert &= ~(1<<nr))

    //  -------------------------------------------------------------
    //    Nucleo Board
    //  -------------------------------------------------------------
    #if (boardversion == 0)                                       //   originales Nucleo Board


      #define lcd_d0_init()   PA9_output_init()
      #define lcd_d0_set()    PA9_set()
      #define lcd_d0_clr()    PA9_clr()

      #define lcd_d1_init()   PC7_output_init()
      #define lcd_d1_set()    PC7_set()
      #define lcd_d1_clr()    PC7_clr()

      #define lcd_d2_init()   PA10_output_init()
      #define lcd_d2_set()    PA10_set()
      #define lcd_d2_clr()    PA10_clr()

      #define lcd_d3_init()   PB3_output_init()
      #define lcd_d3_set()    PB3_set()
      #define lcd_d3_clr()    PB3_clr()

      #define lcd_d4_init()   PB5_output_init()
      #define lcd_d4_set()    PB5_set()
      #define lcd_d4_clr()    PB5_clr()

      #define lcd_d5_init()   PB4_output_init()
      #define lcd_d5_set()    PB4_set()
      #define lcd_d5_clr()    PB4_clr()

      #define lcd_d6_init()   PB10_output_init()
      #define lcd_d6_set()    PB10_set()
      #define lcd_d6_clr()    PB10_clr()

      #define lcd_d7_init()   PA8_output_init()
      #define lcd_d7_set()    PA8_set()
      #define lcd_d7_clr()    PA8_clr()

      #define lcd_rd_init()   PA0_input_init()
      #define lcd_rd_set()    PA0_set()
      #define lcd_rd_clr()    PA0_clr()

      #define lcd_wr_init()   PA1_output_init()
      #define lcd_wr_set()    PA1_set()
      #define lcd_wr_clr()    PA1_clr()

      #define lcd_rs_init()   PA4_output_init()
      #define lcd_rs_set()    PA4_set()
      #define lcd_rs_clr()    PA4_clr()

      #define lcd_cs_init()   PB0_output_init()
      #define lcd_cs_set()    PB0_set()
      #define lcd_cs_clr()    PB0_clr()

      #define lcd_rst_init()   PC1_output_init()
      #define lcd_rst_set()    PC1_set()
      #define lcd_rst_clr()    PC1_clr()

    #endif

    //  -------------------------------------------------------------
    //    Selfmade STM32 Board r3
    //  -------------------------------------------------------------
    #if (boardversion == 1)

      // noch kein eigenes STM32F4 Board verfuegbar

    #endif

  #endif        // USE_8BIT_TFT

#endif
